/*  Project LilBook v2.0
    
    Copyright  1994. All Rights Reserved.

    SUBSYSTEM:    lilbook.exe Application
    FILE:         lilbkapp.cpp
    AUTHOR:       Michael C. Laskie
                  Included Steve Saxon's ToolTips class 


    OVERVIEW
    ========
    Source file for implementation of LilBookApp (TApplication).      
*/


#include <owl\owlpch.h>
#pragma hdrstop
#include <stdio.h>
#include <share.h>
#include "lilbkapp.h"
#include "llbkabtd.h"                        // Definition of about dialog.

extern BOOL nChecked;
const char HelpFileName[] = "lilbook.hlp";

// Lilbook Field sizes
const int LEN_FNAME 	= 19;
const int LEN_LNAME 	= 19;
const int LEN_PHONE 	= 16;
const int LEN_BIRTHDAY 	= 13;

// The Lil Book
struct LilBook {
  char FName[LEN_FNAME + 1];
  char LName[LEN_FNAME + 1];
  char Phone[LEN_PHONE + 1];
  char Birth[LEN_BIRTHDAY + 1];
  char DelFlag[2];
  int  crlf;
} Book;
const int PAGE = sizeof(Book);
const int NFIELDS = 6;

FILE *ghfLilFile;

//{{LilBookApp Implementation}}


DEFINE_RESPONSE_TABLE1(LilBookApp, TApplication)
//{{LilBookAppRSP_TBL_BEGIN}}
	EV_COMMAND(CM_FILENEW, CmFileNew),
	EV_COMMAND(CM_FILEOPEN, CmFileOpen),
	EV_COMMAND(CM_FILECLOSE, CmFileClose),
	EV_COMMAND(CM_FILEPRINT, CmFilePrint),
	EV_COMMAND(CM_FILEPRINTERSETUP, CmFilePrintSetup),
	EV_COMMAND(CM_FILEPRINTPREVIEW, CmFilePrintPreview),
	EV_COMMAND_ENABLE(CM_FILEPRINT, CmPrintEnable),
	EV_COMMAND_ENABLE(CM_FILEPRINTERSETUP, CmPrintEnable),
	EV_COMMAND_ENABLE(CM_FILEPRINTPREVIEW, CmPrintEnable),
	EV_COMMAND(CM_HELPCONTENTS, CmHelpContents),
	EV_COMMAND(CM_HELPUSING, CmHelpUsing),
	EV_COMMAND(CM_HELPABOUT, CmHelpAbout),
	EV_COMMAND(CM_BACKWARD, CmBackward),
	EV_COMMAND(CM_FORWARD, CmForward),
	EV_COMMAND(CM_REWIND, CmRewind),
	EV_WM_WININICHANGE,
	EV_COMMAND(CM_EDITFIND, CmEditFind),
	EV_COMMAND(CM_EDITFINDNEXT, CmEditFindNext),
	EV_COMMAND(CM_FILESAVE, CmFileSave),
	//{{LilBookAppRSP_TBL_END}}
END_RESPONSE_TABLE;


class SDIDecFrame : public TDecoratedFrame {
public:
	SDIDecFrame (TWindow *parent, const char far *title, TWindow *clientWnd, BOOL trackMenuSelection = FALSE, TModule *module = 0) :
            TDecoratedFrame(parent, title, clientWnd, trackMenuSelection, module)
      {  }
    ~SDIDecFrame ()
      {  }

    void Paint (TDC& dc, BOOL erase, TRect& rect);
};


LilBookApp::LilBookApp () : TApplication("Lil Blue Book")
{
    HelpState = FALSE;
    ContextHelp = FALSE;
    HelpCursor = 0;

    Printer = 0;
    Printing = FALSE;

	FileData.Flags = OFN_FILEMUSTEXIST | OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT;
    FileData.SetFilter("Lil db Files (*.ldb)|*.ldb|All Files (*.*)|*.*|");

 	// INSERT>> Your constructor code here.
	// From LilBook v1.0
	nChecked = 0;
	nFound = 0;

}


LilBookApp::~LilBookApp ()
{
    if (Printer)
        delete Printer;

    // INSERT>> Your destructor code here.

}


BOOL LilBookApp::CanClose ()
{
    BOOL result = TApplication::CanClose();

	if (result && HelpState)
        MainWindow->WinHelp(HelpFileName, HELP_QUIT, 0L);

    return result;
}


void LilBookApp::SetupSpeedBar (TDecoratedFrame *frame)
{
	// TControlBar* cb = new TControlBar(frame);
	TControlBar* cb = new TTipControlBar(tooltip, frame);
	cb->Insert(*new TButtonGadget(CM_FILENEW, CM_FILENEW));
	cb->Insert(*new TButtonGadget(CM_FILEOPEN, CM_FILEOPEN));
	cb->Insert(*new TButtonGadget(CM_FILESAVE, CM_FILESAVE));
	cb->Insert(*new TSeparatorGadget(6));
	cb->Insert(*new TButtonGadget(CM_FILEPRINT, CM_FILEPRINT));
	cb->Insert(*new TSeparatorGadget(6));
	cb->Insert(*new TButtonGadget(CM_EDITCUT, CM_EDITCUT));
	cb->Insert(*new TButtonGadget(CM_EDITCOPY, CM_EDITCOPY));
	cb->Insert(*new TButtonGadget(CM_EDITPASTE, CM_EDITPASTE));
	cb->Insert(*new TSeparatorGadget(6));
	cb->Insert(*new TButtonGadget(CM_EDITUNDO, CM_EDITUNDO));
	cb->Insert(*new TSeparatorGadget(6));
	cb->Insert(*new TButtonGadget(CM_FORWARD, CM_FORWARD));
	cb->Insert(*new TButtonGadget(CM_BACKWARD, CM_BACKWARD));
	cb->Insert(*new TButtonGadget(CM_REWIND, CM_REWIND));
	cb->Insert(*new TSeparatorGadget(6));
	cb->Insert(*new TButtonGadget(CM_EDITFIND, CM_EDITFIND));
	cb->Insert(*new TButtonGadget(CM_EDITFINDNEXT, CM_EDITFINDNEXT));
	cb->Insert(*new TSeparatorGadget(6));
//  cb->Insert(*new TButtonGadget(CM_FILEPRINTPREVIEW, CM_FILEPRINTPREVIEW));
	cb->Insert(*new TButtonGadget(CM_HELPCONTENTS, CM_HELPCONTENTS));

    cb->SetHintMode(TGadgetWindow::EnterHints);

    frame->Insert(*cb, TDecoratedFrame::Top);
}


void LilBookApp::InitMainWindow ()
{
	Client = new TMainDlg(0, IDD_MAINDLG);
	SDIDecFrame *frame = new SDIDecFrame(0, GetName(), Client, TRUE);

	// Override the default window style for the main window.
	frame->Attr.Style |= WS_BORDER | WS_CAPTION | WS_MINIMIZEBOX | WS_SYSMENU | WS_THICKFRAME | WS_VISIBLE;
	frame->Attr.Style &= ~(WS_CHILD | WS_CLIPCHILDREN | WS_MAXIMIZEBOX);

	nCmdShow = nCmdShow != SW_SHOWMINIMIZED ? SW_SHOWNORMAL : nCmdShow;

/*	frame->Attr.X = 80;
	frame->Attr.Y = 45;
	frame->Attr.W = 500;
	frame->Attr.H = 350;
*/
	frame->SetIcon(this, IDI_LILBOOK);
	frame->AssignMenu(SDI_MENU);
	frame->Attr.AccelTable = SDI_MENU;

	SetupSpeedBar(frame);

    TStatusBar *sb = new TTipStatusBar(tooltip, frame, TGadget::Recessed,
                                    TStatusBar::CapsLock        |
                                    TStatusBar::NumLock         |
                                    TStatusBar::ScrollLock      |
                                    TStatusBar::Overtype);
    frame->Insert(*sb, TDecoratedFrame::Bottom);
  
    MainWindow = frame;

    EnableCtl3d(TRUE);
    EnableBWCC(TRUE);

	// From LilBook v1.0 
	EditIDC_FName 	 = new TEdit(Client, IDC_FName, LEN_FNAME + 1);
	EditIDC_LName 	 = new TEdit(Client, IDC_LName, LEN_LNAME + 1);
	EditIDC_Phone 	 = new TEdit(Client, IDC_Phone, LEN_PHONE + 1);
	EditIDC_Birthday = new TEdit(Client, IDC_Birthday, LEN_BIRTHDAY + 1);
	EdChkBox		 = new TCheckBox(Client, IDC_CHECKUP, NULL);
}


void LilBookApp::CmFileNew ()
{
   ClearPage();
   EdChkBox->Uncheck();
   nChecked = 0;
}


void LilBookApp::CmFileOpen ()
{
    *FileData.FileName = 0;
    if (Client->CanClose())
        if (TFileOpenDialog(MainWindow, FileData).Execute() == IDOK)
            OpenFile();
}


void LilBookApp::OpenFile (const char *fileName)
{
    if (fileName)
        lstrcpy(FileData.FileName, fileName);

	ghfLilFile = _fsopen(FileData.FileName, "rb+", SH_DENYNO);
	if (ghfLilFile == NULL) {
		ghfLilFile = _fsopen(FileData.FileName, "wb+", SH_DENYNO);
		if (ghfLilFile == NULL)
			MessageBox(MainWindow->HWindow, "Cant open new file!", "Debug",MB_OK);

	}
}


void LilBookApp::CmFileClose ()
{
}


void LilBookApp::CmFileSave ()
{
	if (FetchData()) {
		Book.DelFlag[0] = '\0';
		Book.crlf = 0x0A0D;
		if (!ghfLilFile)
			MessageBox(MainWindow->HWindow, "Open a File!", "Save",MB_OK);
		else {
			if (nChecked)                 	// If update check box on
				// update a record
				LilStepBak();
			else
				// write to end of file
				BigStepFor();

			WriteRec();
			ClearMoFlags();
		}
	}
}


void SDIDecFrame::Paint (TDC&, BOOL, TRect& rect)
{
	LilBookApp *theApp = TYPESAFE_DOWNCAST(GetApplication(), LilBookApp);
	if (theApp) {
        if (theApp->Printing && theApp->Printer && !rect.IsEmpty()) {
            TSize   pageSize(rect.right - rect.left, rect.bottom - rect.top);

        }
    }
}


void LilBookApp::CmFilePrint ()
{
    if (!Printer)
        Printer = new TPrinter;

    APXPrintOut printout(Printer, "Title", MainWindow);
    printout.SetBanding(TRUE);

    Printing = TRUE;

    Printer->Print(MainWindow, printout, TRUE);

    Printing = FALSE;
}


void LilBookApp::CmFilePrintSetup ()
{
    if (!Printer)
        Printer = new TPrinter;

    Printer->Setup(MainWindow);
}


void LilBookApp::CmFilePrintPreview ()
{
/*    SDIDecFrame *sdiFrame = TYPESAFE_DOWNCAST(MainWindow, SDIDecFrame);
	if (sdiFrame) {
		if (Printer)
			Printer = new TPrinter;

		Printing = TRUE;

		PreviewWindow *prevW = new PreviewWindow(sdiFrame, Printer, sdiFrame, "Print Preview", new TLayoutWindow(0));
		prevW->Create();

		BeginModal(MainWindow);

		Printing = FALSE;

		MainWindow->SetRedraw(TRUE);
		MainWindow->Invalidate();

		prevW->Destroy();
		delete prevW;
	}
*/
}


void LilBookApp::CmPrintEnable (TCommandEnabler &tce)
{
	if (!Printer) {
		Printer = new TPrinter;

		tce.Enable(Printer->GetSetup().Error == 0);
	} else
        tce.Enable(Printer->GetSetup().Error == 0);
}


void LilBookApp::CmHelpContents ()
{
    HelpState = MainWindow->WinHelp(HelpFileName, HELP_CONTENTS, 0L);
}


void LilBookApp::CmHelpUsing ()
{
    HelpState = MainWindow->WinHelp(HelpFileName, HELP_HELPONHELP, 0L);
}


// Menu Help About lilbook.exe command
void LilBookApp::CmHelpAbout ()
{
    LilBookAboutDlg(MainWindow).Execute();
}


BOOL LilBookApp::ProcessAppMsg (MSG& msg)
{
    if (msg.message == WM_COMMAND) {
        if (ContextHelp || (GetKeyState(VK_F1) < 0)) {
            ContextHelp = FALSE;
            MainWindow->WinHelp(HelpFileName, HELP_CONTEXT, msg.wParam);
            return TRUE;
        }
    } else
        switch (msg.message) {
        case WM_KEYDOWN:
            if (msg.wParam == VK_F1) {
                if (::GetKeyState(VK_SHIFT) < 0) {
                    ContextHelp = TRUE;
                    HelpCursor = ::LoadCursor(MainWindow->GetModule()->GetInstance(), MAKEINTRESOURCE(IDC_HELPCURSOR));
                    ::SetCursor(HelpCursor);
                    return TRUE;        // Gobble up the message.
                } else {
                    MainWindow->WinHelp(HelpFileName, HELP_INDEX, 0L);
                    return TRUE;        // Gobble up the message.
                }
            } else {
                if (ContextHelp && (msg.wParam == VK_ESCAPE)) {
                    if (HelpCursor)
                        ::DestroyCursor(HelpCursor);
                    ContextHelp = FALSE;
                    HelpCursor = 0;
                    MainWindow->SetCursor(0, IDC_ARROW);
                    return TRUE;    // Gobble up the message.
                }
            }
            break;

        case WM_MOUSEMOVE:
        case WM_NCMOUSEMOVE:
            if (ContextHelp) {
                ::SetCursor(HelpCursor);
                return TRUE;        // Gobble up the message.
            }
            break;

        case WM_INITMENU:
            if (ContextHelp) {
                ::SetCursor(HelpCursor);
                return TRUE;        // Gobble up the message.
            }
            break;
        
        case WM_ENTERIDLE:
            if (msg.wParam == MSGF_MENU)
                if (GetKeyState(VK_F1) < 0) {
                ContextHelp = TRUE;
                MainWindow->PostMessage(WM_KEYDOWN, VK_RETURN, 0L);
                return TRUE;       // Gobble up the message.
            }
            break;
        
        default:
            ;
        };  // End of switch

    // Continue normal processing.
    return TApplication::ProcessAppMsg(msg);
}


void LilBookApp::EvWinIniChange (char far* section)
{
    if (lstrcmp(section, "windows") == 0) {
        if (Printer) {
            char printDBuffer[255];
            LPSTR printDevice = printDBuffer;
            LPSTR devName = 0;
            LPSTR driverName = 0;
            LPSTR outputName = 0;
        
            if (::GetProfileString("windows", "device", "", printDevice, sizeof(printDevice))) {
                devName = printDevice;
                while (*printDevice) {
                    if (*printDevice == ',') {
                        *printDevice++ = 0;
                        if (!driverName)
                            driverName = printDevice;
                        else
                            outputName = printDevice;
                    } else
                        printDevice = AnsiNext(printDevice);
                }

                if ((Printer->GetSetup().Error != 0)                                ||
                    (lstrcmp(devName, Printer->GetSetup().GetDeviceName()) != 0)    ||
                    (lstrcmp(driverName, Printer->GetSetup().GetDriverName()) != 0) ||
                    (lstrcmp(outputName, Printer->GetSetup().GetOutputName()) != 0)) {
                
                    // New printer installed so get the new printer device now.
                    delete Printer;
                    Printer = new TPrinter;
                }
            } else {
				// No printer installed (GetProfileString failed).
				delete Printer;
				Printer = new TPrinter;
			}
		}
	}
}


/********************************* OWL Main *******************************/
int OwlMain (int , char* [])
{
	LilBookApp     App;
	int            result;

	result = App.Run();

	return result;
}
/*************************** The Lil Blue Book ****************************/

	// Fetch Data From TMainDlg's TEdits **
int LilBookApp::FetchData(void) {
	int nFetchflag = 0;
	UINT nStartPos, nEndPos;

	// Fetch Firstname
	if (EditIDC_FName->IsModified()) {
		nFetchflag = 1;
		memset(Book.FName, ' ', LEN_FNAME);
		EditIDC_FName->GetSelection(nStartPos, nEndPos);

		if ( nStartPos == nEndPos )
			EditIDC_FName->GetText(Book.FName, LEN_FNAME);
		else {
			EditIDC_FName->GetSubText(szHoldstr, nStartPos, nEndPos);
			nFetchflag = IDC_FName;
		}
	}

	// Fetch Lastname
	if (EditIDC_LName->IsModified()) {
		nFetchflag = 1;
		memset(Book.LName, ' ', LEN_LNAME);
		EditIDC_LName->GetSelection(nStartPos, nEndPos);

		if ( nStartPos == nEndPos )
			EditIDC_LName->GetText(Book.LName, LEN_LNAME);
		else {
			EditIDC_LName->GetSubText(szHoldstr, nStartPos, nEndPos);
			nFetchflag = IDC_LName;
		}
	}

	// Fetch Phone Number
	if (EditIDC_Phone->IsModified()) {
		nFetchflag = 1;
		memset(Book.Phone, ' ', LEN_PHONE);
		EditIDC_Phone->GetSelection(nStartPos, nEndPos);

		if ( nStartPos == nEndPos )
			EditIDC_Phone->GetText(Book.Phone, LEN_PHONE);
		else {
			EditIDC_Phone->GetSubText(szHoldstr, nStartPos, nEndPos);
			nFetchflag = IDC_Phone;
		}
	}

	// Fetch Birthday
	if (EditIDC_Birthday->IsModified()) {
		nFetchflag = 1;
		memset(Book.Birth, ' ', LEN_BIRTHDAY);
		EditIDC_Birthday->GetSelection(nStartPos, nEndPos);

		if ( nStartPos == nEndPos )
			EditIDC_Birthday->GetText(Book.Birth, LEN_BIRTHDAY);
		else {
			EditIDC_Birthday->GetSubText(szHoldstr, nStartPos, nEndPos);
			nFetchflag = IDC_Birthday;
		}
	}

	return (nFetchflag);
}

   // Hit Me (fill TEdits) **
void LilBookApp::HitMe(void) {
	EditIDC_FName->SetText(Book.FName);
	EditIDC_LName->SetText(Book.LName);
	EditIDC_Phone->SetText(Book.Phone);
	EditIDC_Birthday->SetText(Book.Birth);
}


   // Clear Page **
void LilBookApp::ClearPage(void) {
	EditIDC_FName->SetText("");
	EditIDC_LName->SetText("");
	EditIDC_Phone->SetText("");
	EditIDC_Birthday->SetText("");
	Book.FName[0] = NULL;
	Book.LName[0] = NULL;
	Book.Phone[0] = NULL;
	Book.Birth[0] = NULL;
	Book.DelFlag[0] = NULL;
}

   // Clear Modify Flags **
void LilBookApp::ClearMoFlags(void) {
	EditIDC_FName->ClearModify();
	EditIDC_LName->ClearModify();
	EditIDC_Phone->ClearModify();
	EditIDC_Birthday->ClearModify();
}

  // Do Search **
int LilBookApp::DoSearch() {
	int len1, len2, nFound = 0;
	HCURSOR hcrOld;

	len1 = strlen(szHoldstr);
	hcrOld = SetCursor(LoadCursor(IDC_WAIT)); // mouse cursor (hour glass on)
	char buf[80];

	while(ReadRec()) {

		switch(nFlag) {

		case  IDC_FName:
			  strncpy(buf, Book.FName, len1);
			  buf[len1] = '\0';
			  len2 = stricmp(buf, szHoldstr);
			  if(len2 == 0)
				 nFound = 1;
			  break;
		case  IDC_LName:
			  strncpy(buf, Book.LName, len1);
			  buf[len1] = '\0';
			  len2 = stricmp(buf, szHoldstr);
			  if(len2 == 0)
				 nFound = 1;
			  break;
		case  IDC_Phone:
			  strncpy(buf, Book.Phone, len1);
			  buf[len1] = '\0';
			  len2 = stricmp(buf, szHoldstr);
			  if(len2 == 0)
				 nFound = 1;
			  break;
		case  IDC_Birthday:
			  strncpy(buf, Book.Birth, len1);
			  buf[len1] = '\0';
			  len2 = stricmp(buf, szHoldstr);
			  if(len2 == 0)
				 nFound = 1;
			  break;
		default: break;
	  }

	  if(nFound)
		if (Book.DelFlag[0] != 'D') break;
	  else nFound = 0;

   }

   SetCursor(hcrOld); // return mouse cursor leftward pointer
   return(nFound);
}

// Lil Events ***********************************************************

   // Handle Search
void LilBookApp::CmEditFind() {
	long lCurpos;
	nFound = 0;				// fetch data sets flag to equal the
	if ((nFlag = FetchData()) > 1) {	// selected text's resouce ID
		if (ghfLilFile == NULL)
			MessageBox(MainWindow->HWindow, "Open a File!", "Search",MB_OK);
		else {
			lCurpos = GetCur();
			if(lCurpos < PAGE) lCurpos = PAGE; // could end up neg
				BigStepBak();
			nFound = DoSearch();
			if (!nFound) {
				SetCur(lCurpos);
				LilStepBak();
				ReadRec();
				MessageBox(MainWindow->HWindow, "Selction not found!", "Search",MB_OK);
			}
			HitMe();   // so good
		}

	}

}

   // Handle Search Again button
void LilBookApp::CmEditFindNext() {
	long lCurpos;
	if (nFound) {
		lCurpos = GetCur();
		nFound = DoSearch();
		if (!nFound) {
			SetCur(lCurpos);
			LilStepBak();
			ReadRec();
			MessageBox(MainWindow->HWindow, "No more found!", "Search Again",MB_OK);
		}
		HitMe(); // HHHit me
	}

}


   // Handle Wipe Clear button *
void LilBookApp::CmWipeClear() {
	ClearPage();
	EdChkBox->Uncheck();
	nChecked = 0;

}

   // Handle Read Forward button *
void LilBookApp::CmForward() {
	long lCurpos;
	if (ghfLilFile == NULL)
		MessageBox(MainWindow->HWindow, "Open a File!", "Browse",MB_OK);
	else {
		lCurpos = GetCur();
		while (ReadRec()) {
			if (Book.DelFlag[0] != 'D') {
				HitMe();
				return;
			}

		}
		MessageBox(MainWindow->HWindow, "Have Reached End of File!", "Browse",MB_OK);
		SetCur(lCurpos);
	}

}

   // Handle Read Backward button
void LilBookApp::CmBackward() {
	long lCurpos;

	if (ghfLilFile == NULL)
		MessageBox(MainWindow->HWindow, "Open a File!", "Browse",MB_OK);
	else {
		lCurpos = GetCur();
		while(!feof(ghfLilFile)) {
			if ((lCurpos -= (2*PAGE)) >= 0l) {	// if can read back
				SetCur(lCurpos);
				ReadRec();
				if (Book.DelFlag[0] != 'D') {
					HitMe();
					break;
				}
			}
			else {
				MessageBox(MainWindow->HWindow, "Beginning of File!", "Browse", MB_OK);
				BigStepBak(); 	// an easy way out
				while (ReadRec()) {
					if (Book.DelFlag[0] != 'D') {
						HitMe();
						return;
					}
				}
			}
		}
	}
}

   // Handle Rewind Button
void LilBookApp::CmRewind() {
	if (ghfLilFile == NULL)
		MessageBox(MainWindow->HWindow, "Open a File!", "Rewind",MB_OK);
	else {
		BigStepBak();
		while (ReadRec()) {
			if (Book.DelFlag[0] != 'D') {
				HitMe();
				return;
			}

		}
		MessageBox(MainWindow->HWindow, "File Empty!", "Rewind",MB_OK);
	}

}

   // Handle Delete Button
void LilBookApp::CmDelete() {
	char buf[80];
	if (ghfLilFile != NULL) {
		LilStepBak();
		sprintf(buf, "%s %s", Book.FName, Book.LName);
		if (MessageBox(MainWindow->HWindow, buf, "Delete",MB_OKCANCEL) == IDOK) {
			Book.DelFlag[0] = 'D';
			WriteRec();
			ClearMoFlags();
			ClearPage();
		}
		else
			LilStepFor();
	}
}


// ********** File I/O *********************
   // Read Rec **
int LilBookApp::ReadRec(void) {
	return(fread(&Book, PAGE, 1, ghfLilFile));
}

   // Write Rec **
int LilBookApp::WriteRec(void) {
size_t cbWrite = 0;
long lCurpos;
   lCurpos = GetCur();
   cbWrite = fwrite(&Book, PAGE, 1, ghfLilFile);
   SetCur(lCurpos+PAGE);
   return(cbWrite);
}

// File Cursor Routines

   // Get cursor (to save)
long LilBookApp::GetCur(void) {
   return ftell(ghfLilFile);
}

   // Set cursor (to resume)
int LilBookApp::SetCur(long pos) {
   return (fseek(ghfLilFile, pos, 0));
}

   // Lil step Forward **
void LilBookApp::LilStepFor(void) {
   fseek(ghfLilFile, PAGE, 1);
}

   // Lil step Backward **
void LilBookApp::LilStepBak(void) {
   fseek(ghfLilFile, -PAGE, 1);
}

   // Big Step Forward (to end) **
void LilBookApp::BigStepFor(void) {
   fseek(ghfLilFile, 0L, 2);
}

   // Big Step Back (to begining) **
void LilBookApp::BigStepBak(void) {
   fseek(ghfLilFile, 0L, 0);
}

/************************************************************************/
// End of Source




