#if !defined(__lilbkapp_h)              // Sentry, use file only if it's not already included.
#define __lilbkapp_h

/*  Project LilBook
    
    Copyright  1994. All Rights Reserved.

    SUBSYSTEM:    lilbook.exe Application
    FILE:         lilbkapp.h
    AUTHOR:       Michael C. Laskie


    OVERVIEW
    ========
    Class definition for LilBookApp (TApplication).      
*/


#include <owl\owlpch.h>
#pragma hdrstop

#include <owl\statusba.h>
#include <owl\controlb.h>
#include <owl\buttonga.h>
#include <owl\printer.h>
#include <owl\opensave.h>
#include <owl\edit.h>
#include <owl\checkbox.h>
#include <owl\listbox.h>

#include "apxprint.h"
#include "apxprev.h"

#include "lilbkapp.rh"            // Definition of all resources.
#include "tmaindlg.h"
#include "ttooltip.h"


//{{TApplication = LilBookApp}}
class LilBookApp : public TApplication {
private:
	TWindow *Client;                                 // Client window for the frame.
	TOpenSaveDialog::TData FileData;                    // Data to control open/saveas standard dialog.
	BOOL            HelpState;                          // Has the help engine been used.
	BOOL            ContextHelp;                        // SHIFT-F1 state (context sensitive HELP)
	HCURSOR         HelpCursor;                         // Context sensitive help cursor
	TEdit *EditIDC_FName;
	TEdit *EditIDC_LName;
	TEdit *EditIDC_Phone;
	TEdit *EditIDC_Birthday;
	TCheckBox *EdChkBox;
	TToolTip	tooltip;

private:
	 void SetupSpeedBar (TDecoratedFrame *frame);

public:
	 LilBookApp ();
	 virtual ~LilBookApp ();

	 void OpenFile (const char *fileName = 0);
	 // Public data members used by the print menu commands and Paint routine in MDIChild.
	 TPrinter        *Printer;                           // Printer support.
    BOOL            Printing;                           // Printing in progress.

	/* From LilBook v1.0 */
	// Data members
	HCURSOR hcrWait;
	int  nFlag, nFound;
	char szName[256];
	char szHoldstr[29];

	// Function Members
							// File I/O (coded at end of source)
	int  ReadRec(void);			// Read a record from the file
	int  WriteRec(void);		// Write a record from the file
	long GetCur(void);                  // Cursor Positioning...
	int  SetCur(long);
	void LilStepFor(void);
	void LilStepBak(void);
	void BigStepFor(void);
	void BigStepBak(void);

	int  DoSearch(void);
	void ClearMoFlags(void);
	void HitMe(void);
	void ClearPage(void);
	int  FetchData(void);

	/* end From LilBook v1.0 */

//{{LilBookAppVIRTUAL_BEGIN}}
public:
    virtual void InitMainWindow();
    virtual BOOL CanClose ();
    virtual BOOL ProcessAppMsg (MSG& msg);
    void CmFileSave ();
	void CmDelete();
//{{LilBookAppVIRTUAL_END}}

//{{LilBookAppRSP_TBL_BEGIN}}
protected:
    void CmFileNew ();
    void CmFileOpen ();
    void CmFileClose ();
    void CmFilePrint ();
    void CmFilePrintSetup ();
    void CmFilePrintPreview ();
    void CmPrintEnable (TCommandEnabler &tce);
    void CmHelpContents ();
    void CmHelpUsing ();
    void CmHelpAbout ();
    void EvWinIniChange (char far* section);

    // From Lilbook v1.0
	void CmSave();
	void CmSearch();
	void CmSearchAgain();
	void CmWipeClear();
	void CmForward();
	void CmBackward();
	void CmRewind();
    void CmEditFind ();
    void CmEditFindNext ();
    void BNClicked();
    UINT EvGetDlgCode (MSG far* msg);
//{{LilBookAppRSP_TBL_END}}
  DECLARE_RESPONSE_TABLE(LilBookApp);
};    //{{LilBookApp}}

#endif                                      // __lilbkapp_h sentry.
